Class: MythicBeasts::DNS::EmailAuth::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/mythic_beasts/dns/email_auth.rb

Overview

Aggregated result of all email authentication checks

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#dkim ⇒ Object

Returns the value of attribute dkim

Returns:

  • (Object) —

    the current value of dkim



20
21
22
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20

def dkim
  @dkim
end

#dmarc ⇒ Object

Returns the value of attribute dmarc

Returns:

  • (Object) —

    the current value of dmarc



20
21
22
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20

def dmarc
  @dmarc
end

#errors ⇒ Object

Returns the value of attribute errors

Returns:

  • (Object) —

    the current value of errors



20
21
22
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20

def errors
  @errors
end

#spf ⇒ Object

Returns the value of attribute spf

Returns:

  • (Object) —

    the current value of spf



20
21
22
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20

def spf
  @spf
end

#warnings ⇒ Object

Returns the value of attribute warnings

Returns:

  • (Object) —

    the current value of warnings



20
21
22
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20

def warnings
  @warnings
end

Instance Method Details

#valid? ⇒ Boolean

Returns true if no errors were found across all checks.

Returns:

  • (Boolean) —

    true if no errors were found across all checks



22
23
24
# File 'lib/mythic_beasts/dns/email_auth.rb', line 22

def valid?
  errors.empty?
end