Class: MythicBeasts::DNS::EmailAuth::Result
- Inherits:
-
Struct
- Object
- Struct
- MythicBeasts::DNS::EmailAuth::Result
- Defined in:
- lib/mythic_beasts/dns/email_auth.rb
Overview
Aggregated result of all email authentication checks
Instance Attribute Summary collapse
-
#dkim ⇒ Object
Returns the value of attribute dkim.
-
#dmarc ⇒ Object
Returns the value of attribute dmarc.
-
#errors ⇒ Object
Returns the value of attribute errors.
-
#spf ⇒ Object
Returns the value of attribute spf.
-
#warnings ⇒ Object
Returns the value of attribute warnings.
Instance Method Summary collapse
-
#valid? ⇒ Boolean
True if no errors were found across all checks.
Instance Attribute Details
#dkim ⇒ Object
Returns the value of attribute dkim
20 21 22 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20 def dkim @dkim end |
#dmarc ⇒ Object
Returns the value of attribute dmarc
20 21 22 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20 def dmarc @dmarc end |
#errors ⇒ Object
Returns the value of attribute errors
20 21 22 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20 def errors @errors end |
#spf ⇒ Object
Returns the value of attribute spf
20 21 22 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20 def spf @spf end |
#warnings ⇒ Object
Returns the value of attribute warnings
20 21 22 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 20 def warnings @warnings end |
Instance Method Details
#valid? ⇒ Boolean
Returns true if no errors were found across all checks.
22 23 24 |
# File 'lib/mythic_beasts/dns/email_auth.rb', line 22 def valid? errors.empty? end |